@@ -548,6 +548,28 @@
         <source>Page number:</source>
         <translation>Pagina numero:</translation>
     </message>
+    <message>
+        <source>Open URL</source>
+        <translation>Apri URL</translation>
+    </message>
+    <message>
+        <source>You are in the process of opening the URL %1. Opening unknown or untrusted web adresses can be a security risk.
+Do you want to continue?</source>
+        <translation>Stai per aprire l&apos;URL %1. L&apos;apertura di indirizzi web sconosciuti o non verificati comporta rischi per la sicurezza.
+Vuoi continuare?</translation>
+    </message>
+    <message>
+        <source>Custom...</source>
+        <translation>Persolnalizza...</translation>
+    </message>
+    <message>
+        <source>Set Zoom</source>
+        <translation>Imposta zoom</translation>
+    </message>
+    <message>
+        <source>Zoom level:</source>
+        <translation>Livello di zoom</translation>
+    </message>
 </context>
 <context>
     <name>PDFFindDialog</name>
@@ -732,7 +754,7 @@
     </message>
     <message>
         <source> dpi</source>
-        <translation> dpi (punti pp)</translation>
+        <translation type="obsolete"> dpi (punti pp)</translation>
     </message>
     <message>
         <source>Typesetting</source>
@@ -1014,6 +1036,40 @@
         <translation>Resistro (%1)</translation>
     </message>
 </context>
+<context>
+    <name>ScreenCalibrationWidget</name>
+    <message>
+        <source>Drag the ruler or change the value to match real world lengths.
+Common paper sizes are marked as well (you may need to resize the dialog window to see them).
+Use the context menu to change the units.</source>
+        <translation>Trascina il righello o cambia il valore per adeguarlo alla lunghezza reale.
+I formati di carta più comunu sono contrassegnati (potresti dover ridimensionare la finestra per riuscire a vederli).
+Usa il menù constestuale per cambiare le unità.</translation>
+    </message>
+    <message>
+        <source> dpi</source>
+        <extracomment>dots per inch</extracomment>
+        <translation>dpi (punti pp)</translation>
+    </message>
+    <message>
+        <source>DIN A4</source>
+        <translation>DIN A4</translation>
+    </message>
+    <message>
+        <source>Letter</source>
+        <translation>Letter</translation>
+    </message>
+    <message>
+        <source>cm</source>
+        <extracomment>this refers to the length unit of centimeters</extracomment>
+        <translation>cm</translation>
+    </message>
+    <message>
+        <source>in</source>
+        <extracomment>this refers to the length unit of inches</extracomment>
+        <translation>pollici</translation>
+    </message>
+</context>
 <context>
     <name>ScriptManager</name>
     <message>
